@@ -1,25 +1,9 @@
 /*
   This file is part of the KDE reminder agent.
 
-  Copyright (c) 2000 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2000 Cornelius Schumacher <schumacher@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 #ifndef KORGAC_ALARMDIALOG_H
 #define KORGAC_ALARMDIALOG_H
@@ -69,7 +53,6 @@ public:
     ~AlarmDialog();
 
     void addIncidence(const Akonadi::Item &incidence, const QDateTime &reminderAt, const QString &displayText);
-    void setRemindAt(const QDateTime &dt);
     void eventNotification();
 
 public Q_SLOTS:
@@ -111,7 +94,7 @@ private Q_SLOTS:
 private:
     void update();
     void updateButtons();
-    typedef QList<ReminderTreeItem *> ReminderList;
+    using ReminderList = QList<ReminderTreeItem *>;
 
     static Q_REQUIRED_RESULT QDateTime triggerDateForIncidence(const KCalendarCore::Incidence::Ptr &inc, const QDateTime &reminderAt, QString &displayStr);
 
@@ -124,7 +107,6 @@ private:
     // opens directly
     Q_REQUIRED_RESULT bool openIncidenceEditorNG(const Akonadi::Item &incidence);
 
-    Q_REQUIRED_RESULT bool startKOrganizer();
     ReminderTreeItem *searchByItem(const Akonadi::Item &incidence);
     void setTimer();
     void dismiss(const ReminderList &selections);
