@@ -1,27 +1,11 @@
 /*
   This file is part of KOrganizer.
 
-  Copyright (c) 2000,2001,2003,2004 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
-  Copyright (c) 2005 Rafal Rzepecki <divide@users.sourceforge.net>
+  SPDX-FileCopyrightText: 2000, 2001, 2003, 2004 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2005 Rafal Rzepecki <divide@users.sourceforge.net>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #ifndef KORG_CALENDARVIEW_H
@@ -397,7 +381,7 @@ public Q_SLOTS:
 
     void newJournal();
     void newJournal(const QDate &date);
-    void newJournal(const QString &text, const QDate &date = QDate());
+    void newJournal(const QString &text, QDate date = QDate());
     void newJournal(const Akonadi::Collection &collection);
 
     void configureCurrentView();
@@ -406,7 +390,7 @@ public Q_SLOTS:
     void toggleTodoCompleted(const Akonadi::Item &incidence);
     void copyIncidenceToResource(const Akonadi::Item &incidence, const Akonadi::Collection &col);
     void moveIncidenceToResource(const Akonadi::Item &incidence, const Akonadi::Collection &col);
-    void dissociateOccurrences(const Akonadi::Item &incidence, const QDate &date);
+    void dissociateOccurrences(const Akonadi::Item &incidence, QDate date);
 
     /**
       Check if clipboard contains vCalendar event. The signal pasteEnabled() is
@@ -541,10 +525,10 @@ public Q_SLOTS:
     void showEventViewer(bool);
 
     /** Move the current view date to the specified date */
-    void goDate(const QDate &date);
+    void goDate(QDate date);
 
     /** Show the given date without changing date selection length. */
-    void showDate(const QDate &date);
+    void showDate(QDate date);
 
     /** Move the current view date to today */
     void goToday();
@@ -574,7 +558,7 @@ public Q_SLOTS:
     void showErrorMessage(const QString &);
     void schedule(KCalendarCore::iTIPMethod, const Akonadi::Item &incidence);
     void addIncidenceOn(const Akonadi::Item &incidence, const QDate &);
-    void moveIncidenceTo(const Akonadi::Item &incidence, const QDate &);
+    void moveIncidenceTo(const Akonadi::Item &incidence, QDate);
     void filterActivated(int filterNum);
 
     void resourcesChanged();
@@ -653,7 +637,6 @@ private Q_SLOTS:
     void onTodosPurged(bool success, int numDeleted, int numIgnored);
 
 private:
-    void init();
     Akonadi::Collection selectedCollection() const;
     Akonadi::Collection::List checkedCollections() const;
 
