@@ -1,25 +1,9 @@
 /*
   This file is part of KOrganizer.
 
-  Copyright (c) 2015 Sandro Knauß <knauss@kolabsys.com>
+  SPDX-FileCopyrightText: 2015 Sandro Knauß <knauss@kolabsys.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "searchcollectionhelper.h"
@@ -70,7 +54,7 @@ void SearchCollectionHelper::onSearchCollectionsFetched(KJob *job)
     if (job->error()) {
         qCWarning(KORGANIZER_LOG) << "Search failed: " << job->errorString();
     } else {
-        Akonadi::CollectionFetchJob *fetchJob = static_cast<Akonadi::CollectionFetchJob *>(job);
+        auto *fetchJob = static_cast<Akonadi::CollectionFetchJob *>(job);
         const Akonadi::Collection::List lstCols = fetchJob->collections();
         for (const Akonadi::Collection &col : lstCols) {
             if (col.name() == QLatin1String("OpenInvitations")) {
@@ -98,7 +82,7 @@ void SearchCollectionHelper::updateSearchCollection(Akonadi::Collection col, KCa
     }
 
     if (!col.isValid()) {
-        Akonadi::SearchCreateJob *job = new Akonadi::SearchCreateJob(name, query);
+        auto *job = new Akonadi::SearchCreateJob(name, query);
         job->setRemoteSearchEnabled(false);
         job->setSearchMimeTypes(QStringList() << KCalendarCore::Event::eventMimeType()
                                               << KCalendarCore::Todo::todoMimeType()
@@ -107,15 +91,15 @@ void SearchCollectionHelper::updateSearchCollection(Akonadi::Collection col, KCa
                 &SearchCollectionHelper::createSearchJobFinished);
         qCDebug(KORGANIZER_LOG) << "We have to create a " << name << " virtual Collection";
     } else {
-        Akonadi::PersistentSearchAttribute *attribute
+        auto *attribute
             = col.attribute<Akonadi::PersistentSearchAttribute>(Akonadi::Collection::AddIfMissing);
-        Akonadi::EntityDisplayAttribute *displayname
+        auto *displayname
             = col.attribute<Akonadi::EntityDisplayAttribute >(Akonadi::Collection::AddIfMissing);
         attribute->setQueryString(QString::fromLatin1(query.toJSON()));
         attribute->setRemoteSearchEnabled(false);
         displayname->setDisplayName(displayName);
         col.setEnabled(true);
-        Akonadi::CollectionModifyJob *job = new Akonadi::CollectionModifyJob(col, this);
+        auto *job = new Akonadi::CollectionModifyJob(col, this);
         connect(job, &Akonadi::CollectionModifyJob::result, this,
                 &SearchCollectionHelper::modifyResult);
         qCDebug(KORGANIZER_LOG) << "updating " << name << " (" << col.id()
@@ -141,7 +125,7 @@ void SearchCollectionHelper::updateOpenInvitation()
 
 void SearchCollectionHelper::createSearchJobFinished(KJob *job)
 {
-    Akonadi::SearchCreateJob *createJob = qobject_cast<Akonadi::SearchCreateJob *>(job);
+    auto *createJob = qobject_cast<Akonadi::SearchCreateJob *>(job);
     const Akonadi::Collection searchCollection = createJob->createdCollection();
     if (job->error()) {
         qCWarning(KORGANIZER_LOG) << "Error occurred " << searchCollection.name()
