@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "manageshowcollectionproperties.h"
@@ -29,12 +16,12 @@
 ManageShowCollectionProperties::ManageShowCollectionProperties(
     AkonadiCollectionView *collectionView, QObject *parent)
     : QObject(parent)
+    , mPages{ QStringLiteral("CalendarSupport::CollectionGeneralPage"),
+               QStringLiteral("Akonadi::CachePolicyPage"),
+               QStringLiteral("PimCommon::CollectionAclPage"),
+               QStringLiteral("Akonadi::CollectionMaintenancePage") }
     , mCollectionView(collectionView)
 {
-    mPages = QStringList() << QStringLiteral("CalendarSupport::CollectionGeneralPage")
-                           << QStringLiteral("Akonadi::CachePolicyPage")
-                           << QStringLiteral("PimCommon::CollectionAclPage")
-                           << QStringLiteral("Akonadi::CollectionMaintenancePage");
 }
 
 ManageShowCollectionProperties::~ManageShowCollectionProperties()
@@ -51,7 +38,7 @@ void ManageShowCollectionProperties::showCollectionProperties()
         dlg->raise();
         return;
     }
-    Akonadi::CollectionAttributesSynchronizationJob *sync
+    auto *sync
         = new Akonadi::CollectionAttributesSynchronizationJob(col);
     sync->setProperty("collectionId", id);
     connect(sync, &Akonadi::CollectionAttributesSynchronizationJob::result,
@@ -62,7 +49,7 @@ void ManageShowCollectionProperties::showCollectionProperties()
 void ManageShowCollectionProperties::slotCollectionPropertiesContinued(KJob *job)
 {
     if (job) {
-        Akonadi::CollectionAttributesSynchronizationJob *sync
+        auto *sync
             = qobject_cast<Akonadi::CollectionAttributesSynchronizationJob *>(job);
         Q_ASSERT(sync);
         if (sync->property("collectionId") != mCollectionView->currentCalendar().id()) {
@@ -83,7 +70,7 @@ void ManageShowCollectionProperties::slotCollectionPropertiesFinished(KJob *job)
         return;
     }
 
-    Akonadi::CollectionFetchJob *fetch = qobject_cast<Akonadi::CollectionFetchJob *>(job);
+    auto *fetch = qobject_cast<Akonadi::CollectionFetchJob *>(job);
     Q_ASSERT(fetch);
     if (fetch->collections().isEmpty()) {
         qCWarning(KORGANIZER_LOG) << "no collection";
