@@ -1,26 +1,10 @@
 /*
   This file is part of KOrganizer.
 
-  Copyright (C) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
-  Author: Sergio Martins <sergio.martins@kdab.com>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+  SPDX-FileContributor: Sergio Martins <sergio.martins@kdab.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "monthview.h"
@@ -36,8 +20,8 @@ using namespace KOrg;
 MonthView::MonthView(QWidget *parent)
     : KOEventView(parent)
 {
-    QVBoxLayout *layout = new QVBoxLayout(this);
-    layout->setContentsMargins(0, 0, 0, 0);
+    auto *layout = new QVBoxLayout(this);
+    layout->setContentsMargins({});
     mMonthView = new EventViews::MonthView(EventViews::MonthView::Visible, this);
     mMonthView->setPreferences(KOPrefs::instance()->eventViewsPreferences());
     layout->addWidget(mMonthView);
